Learn R Programming

DAISIEprep (version 1.0.1)

GalapagosTrees: Phylogenetic trees of the Galapagos bird lineages and sister species on the mainland.

Description

Each dataset is a phylogenetic tree used to extract the Galapagos avifaunal lineages.

Usage

coccyzus_tree

columbiformes_tree

finches_tree

mimus_tree

myiarchus_tree

progne_tree

pyrocephalus_tree

setophaga_tree

Arguments

Format

A phylo object (from the ape package)

An object of class phylo of length 5.

An object of class phylo of length 4.

An object of class phylo of length 5.

An object of class phylo of length 4.

An object of class phylo of length 5.

An object of class phylo of length 5.

An object of class phylo of length 5.