Learn R Programming

DAISIEprep (version 1.0.1)

Island_colonist-class: Defines the island_tbl class which is used when extracting information from the phylogenetic and island data to be used for constructing a daisie_data_tbl

Description

Defines the island_tbl class which is used when extracting information from the phylogenetic and island data to be used for constructing a daisie_data_tbl

Arguments

Slots

clade_name

character.

status

character.

missing_species

character.

col_time

numeric.

col_max_age

logical.

branching_times

numeric.

min_age

numeric.

species

character.

clade_type

numeric.