Learn R Programming

DAISIEprep (version 1.0.1)

Island_tbl-class: Defines the island_tbl class which is used when extracting information from the phylogenetic and island data to be used for constructing a daisie_data_tbl

Description

Defines the island_tbl class which is used when extracting information from the phylogenetic and island data to be used for constructing a daisie_data_tbl

Arguments

Slots

island_tbl

data frame.

metadata

list.