Learn R Programming

DAISIEprep (version 1.0.1)

all_descendants_conspecific: Checks whether all species given in the descendants vector are the same species.

Description

Checks whether all species given in the descendants vector are the same species.

Usage

all_descendants_conspecific(descendants)

Value

Boolean

Arguments

descendants

A vector character strings with the names of species to determine whether they are the same species.

Examples

Run this code
# Example where species are not conspecific
descendants <- c("bird_a", "bird_b", "bird_c")
all_descendants_conspecific(descendants = descendants)

# Example where species are conspecific
descendants <- c("bird_a_1", "bird_a_2", "bird_a_3")
all_descendants_conspecific(descendants = descendants)

Run the code above in your browser using DataLab