Learn R Programming

DAISIEprep (version 1.0.1)

bind_colonist_to_tbl: Takes an existing instance of an Island_tbl class and bind the information from the instance of an Island_colonist class to it

Description

Takes an existing instance of an Island_tbl class and bind the information from the instance of an Island_colonist class to it

Usage

bind_colonist_to_tbl(island_colonist, island_tbl)

Value

An object of Island_tbl class

Arguments

island_colonist

An instance of the Island_colonist class.

island_tbl

An instance of the Island_tbl class.

Examples

Run this code
island_colonist <- DAISIEprep::island_colonist(
  clade_name = "bird",
  status = "endemic",
  missing_species = 0,
  col_time = 1,
  col_max_age = FALSE,
  branching_times = 0.5,
  species = "bird_a",
  clade_type = 1
)
island_tbl <- island_tbl()
bind_colonist_to_tbl(
  island_colonist = island_colonist,
  island_tbl = island_tbl
)

Run the code above in your browser using DataLab