Learn R Programming

DAISIEprep (version 1.0.1)

coccyzus_phylod: A phylogenetic tree of coccyzus species with endemicity status as tip states.

Description

A phylogenetic tree of coccyzus species with endemicity status as tip states.

Usage

coccyzus_phylod

Arguments

Format

coccyzus_phylod

A phylo4d object (from the phylobase package) with 20 tips and 19 internal nodes.