Learn R Programming

DAISIEprep (version 1.0.1)

columbiformes_phylod: A phylogenetic tree of columbiformes species with endemicity status as tip states.

Description

A phylogenetic tree of columbiformes species with endemicity status as tip states.

Usage

columbiformes_phylod

Arguments

Format

columbiformes_phylod

A phylo4d object (from the phylobase package) with 242 tips and 241 internal nodes.