Extracts the stem age from the phylogeny when the a species is known to belong to a genus but is not itself in the phylogeny and there are members of the same genus are in the phylogeny using the 'asr' extraction method
extract_stem_age_asr(genus_in_tree, phylod)Numeric
A numeric vector that indicates which species in the genus are in the tree
A phylo4d object from the package phylobase containing
phylogenetic and endemicity data for each species.