Learn R Programming

DAISIEprep (version 1.0.1)

finches_phylod: A phylogenetic tree of finches species with endemicity status as tip states.

Description

A phylogenetic tree of finches species with endemicity status as tip states.

Usage

finches_phylod

Arguments

Format

finches_phylod

A phylo4d object (from the phylobase package) with 16 tips and 15 internal nodes.