Learn R Programming

DAISIEprep (version 1.0.1)

get_island_tbl: Accessor functions for the data (slots) in objects of the Island_tbl class

Description

Accessor functions for the data (slots) in objects of the Island_tbl class

Usage

get_island_tbl(x)

# S4 method for Island_tbl get_island_tbl(x)

set_island_tbl(x) <- value

# S4 method for Island_tbl set_island_tbl(x) <- value

get_extracted_species(x)

# S4 method for Island_tbl get_extracted_species(x)

set_extracted_species(x) <- value

# S4 method for Island_tbl set_extracted_species(x) <- value

get_num_phylo_used(x)

# S4 method for Island_tbl get_num_phylo_used(x)

set_num_phylo_used(x) <- value

# S4 method for Island_tbl set_num_phylo_used(x) <- value

Value

Getter function (get_) returns a data frame, the setter function (set_) returns the modified Island_tbl class.

Arguments

x

An object whose class is determined by the signature.

value

A value which can take several forms to be assigned to an object of a class.

Author

Joshua W. Lambert

Examples

Run this code
island_tbl <- island_tbl()
get_island_tbl(island_tbl)
set_island_tbl(island_tbl) <- data.frame(
  clade_name = "birds",
  status = "endemic",
  missing_species = 0,
  branching_times = I(list(c(1.0, 0.5)))
)

Run the code above in your browser using DataLab