Learn R Programming

DAISIEprep (version 1.0.1)

is_identical_island_tbl: Checks whether two Island_tbl objects are identical. If they are different comparisons are made to report which components of the Island_tbls are different.

Description

Checks whether two Island_tbl objects are identical. If they are different comparisons are made to report which components of the Island_tbls are different.

Usage

is_identical_island_tbl(island_tbl_1, island_tbl_2)

Value

Either TRUE or a character string with the differences

Arguments

island_tbl_1

An object of Island_tbl class to be comparedl

island_tbl_2

An object of Island_tbl class to be compared

Examples

Run this code
multi_island_tbl <- multi_extract_island_species(
  multi_phylod = list(
    create_test_phylod(test_scenario = 1),
    create_test_phylod(test_scenario = 1)),
 extraction_method = "min")
is_identical_island_tbl(multi_island_tbl[[1]], multi_island_tbl[[2]])

Run the code above in your browser using DataLab