Learn R Programming

DAISIEprep (version 1.0.1)

mimus_phylod: A phylogenetic tree of mimus species with endemicity status as tip states.

Description

A phylogenetic tree of mimus species with endemicity status as tip states.

Usage

mimus_phylod

Arguments

Format

mimus_phylod

A phylo4d object (from the phylobase package) with 29 tips and 28 internal nodes.