Learn R Programming

DAISIEprep (version 1.0.1)

myiarchus_phylod: A phylogenetic tree of myiarchus species with endemicity status as tip states.

Description

A phylogenetic tree of myiarchus species with endemicity status as tip states.

Usage

myiarchus_phylod

Arguments

Format

myiarchus_phylod

A phylo4d object (from the phylobase package) with 13 tips and 12 internal nodes.