Learn R Programming

DAISIEprep (version 1.0.1)

progne_phylod: A phylogenetic tree of progne species with endemicity status as tip states.

Description

A phylogenetic tree of progne species with endemicity status as tip states.

Usage

progne_phylod

Arguments

Format

progne_phylod

A phylo4d object (from the phylobase package) with 19 tips and 18 internal nodes.