Learn R Programming

DAISIEprep (version 1.0.1)

pyrocephalus_phylod: A phylogenetic tree of pyrocephalus species with endemicity status as tip states.

Description

A phylogenetic tree of pyrocephalus species with endemicity status as tip states.

Usage

pyrocephalus_phylod

Arguments

Format

pyrocephalus_phylod

A phylo4d object (from the phylobase package) with 66 tips and 65 internal nodes.