Learn R Programming

DAISIEprep (version 1.0.1)

setophaga_phylod: A phylogenetic tree of setophaga species with endemicity status as tip states.

Description

A phylogenetic tree of setophaga species with endemicity status as tip states.

Usage

setophaga_phylod

Arguments

Format

setophaga_phylod

A phylo4d object (from the phylobase package) with 19 tips and 18 internal nodes.