write_phylip_biogeo_file: Write biogeography input file for BioGeoBEARS
Description
Write a text file containing occurrence data for all tips in the PHYLIP
format expected by BioGeoBEARS
Usage
write_phylip_biogeo_file(phylod, path_to_biogeo)
Value
Nothing, called for side-effects.
Arguments
- phylod
A phylo4d object from the package phylobase containing
phylogenetic and endemicity data for each species.
- path_to_biogeo
string specifying the path and name to write the file
to.