island_tbl class which is used when extracting information
from the phylogenetic and island data to be used for constructing a
daisie_data_tblDefines the island_tbl class which is used when extracting information
from the phylogenetic and island data to be used for constructing a
daisie_data_tbl
clade_namecharacter.
statuscharacter.
missing_speciescharacter.
col_timenumeric.
col_max_agelogical.
branching_timesnumeric.
min_agenumeric.
speciescharacter.
clade_typenumeric.