Island_tbl-class: Defines the island_tbl class which is used when extracting information
from the phylogenetic and island data to be used for constructing a
daisie_data_tbl
Description
Defines the island_tbl class which is used when extracting information
from the phylogenetic and island data to be used for constructing a
daisie_data_tbl