Learn R Programming

DAISIEprep (version 1.0.1)

extract_nonendemic_forced: Extract non-endemic colonist that is forced to be a singleton by user

Description

Extract non-endemic colonist that is forced to be a singleton by user

Usage

extract_nonendemic_forced(phylod, species_label, island_tbl)

Value

An object of phylo4d class with tip and node data

Arguments

phylod

A phylo4d object from the package phylobase containing phylogenetic and endemicity data for each species.

species_label

The tip label of the species of interest.

island_tbl

An instance of the Island_tbl class.