translate_status: Takes a string of the various ways the island species status can be and
returns a uniform all lower-case string of the same status to make handling
statuses easier in other function
Description
Takes a string of the various ways the island species status can be and
returns a uniform all lower-case string of the same status to make handling
statuses easier in other function
Usage
translate_status(status)
Value
Character string
Arguments
status
Character endemicity status of the colonising clade. Either
"endemic" or "nonendemic".